%global commit 930fef3410c18685ad7995a77f2169c4a76e7c50
%global shortcommit %(c=%{commit}; echo ${c:0:7})

%global varnishver 4.0.4
%global vbranch .4.0
%global vabi 1.2

Summary:   Control and statistics agent for varnish
Name:      varnish-agent
Version:   4.0.2
Release:   1%{?vbranch}%{?dist}
License:   BSD
Group:     System Environment/Daemons

Source0:   https://github.com/varnish/vagent2/releases/download/%{version}/%{name}-%{version}.tar.gz
Patch1:    varnish-agent-4.0.2.fix_for_i386.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Requires: varnish = %varnishver
Requires: varnishabi-%vabi

%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
BuildRequires: systemd-units
%endif

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool

BuildRequires: varnish-libs-devel = %{varnishver}
BuildRequires: varnish = %{varnishver}
BuildRequires: nc
BuildRequires: sed
BuildRequires: gcc
BuildRequires: curl
BuildRequires: strace
BuildRequires: libmicrohttpd-devel
BuildRequires: python-docutils
BuildRequires: perl(LWP)
BuildRequires: python-demjson
BuildRequires: libedit-devel
%if 0%{?el5} 
BuildRequires: curl-devel
%else
BuildRequires: libcurl-devel
%endif

%description
Varnish Agent is a small daemon meant to communicate with Varnish and other
varnish-related services to allow remote control and monitoring of Varnish.

Required component for running the Varnish Administration Console (VAC) from Varnish Software.

%prep
%setup -q
%patch1 -p0

%build
export RST2MAN=/bin/true
%configure

# Hack for fedora 25, should probably never be used
# as this is fixed in newer releases of varnish-agent
%if 0%{?fedora} >= 25
sed -i 's/-Werror=format-security//' Makefile */Makefile
sed -i 's/-Werror//' Makefile */Makefile
%endif

head -28 src/main.c > LICENSE
make VERBOSE=1

%check
make check || make check VERBOSE=1

%install
make install DESTDIR=%{buildroot}
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
install -D -m 0644 redhat/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -D redhat/%{name}.params %{buildroot}%{_sysconfdir}/varnish/%{name}.params
%else
install -D redhat/%{name}.sysconfig   %{buildroot}/etc/sysconfig/%{name}
install -D redhat/%{name}.initrc      %{buildroot}%{_initrddir}/%{name}
%endif
mkdir -p %{buildroot}/etc/varnish
touch %{buildroot}/etc/varnish/agent_secret
mkdir -p %{buildroot}/var/lib/%{name}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.*
%{_datadir}/%{name}/html
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
%{_unitdir}/%{name}.service
%config(noreplace)%{_sysconfdir}/varnish/%{name}.params
%license LICENSE
%else
%config(noreplace) %{_initrddir}/%{name}
%config(noreplace) /etc/sysconfig/%{name}
%doc LICENSE
%endif
%doc README.rst THANKS
%ghost %attr(600, -, -) /etc/varnish/agent_secret
%attr(-, varnish, varnish) /var/lib/%{name}

%post
test -f /etc/varnish/agent_secret || \
    (echo "varnish:$(head -c 8 /dev/urandom | base64)" > /etc/varnish/agent_secret \
    && chmod 0600 /etc/varnish/agent_secret)
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
%else
/sbin/chkconfig --add %{name}
%endif

%preun
if [ $1 -lt 1 ]; then
%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
%systemd_preun %{name}.service
%else
/sbin/service %{name} stop > /dev/null 2>&1
/sbin/chkconfig --del %{name}
%endif
fi

%changelog
* Thu Dec 08 2016 Ingvar Hagelund <ingvar@redpill-linpro.com> - 4.1.1-1
- New upstream release 4.0.2
- Build against varnish-4.0.4

* Fri Feb 05 2016 Ingvar Hagelund <ingvar@redpill-linpro.com> - 0.5.20160201git28eacbb
- Use name macro extensively to avoid typos, thus also fixing a typo when calling
  systemd_preun macro

* Mon Feb 01 2016 Ingvar Hagelund <ingvar@redpill-linpro.com> - 0.4.20160201git28eacbb
- Updated to new git checkout for varnish-4.1.1 support
- Added missing doc items
- Use systemd_preun macro when available

* Mon Nov 02 2015 Ingvar Hagelund <ingvar@redpill-linpro.com> - 0.3.git.846d880
- Fixed reported 32 bit build bug. Dropped workaround patch.

* Thu Oct 22 2015 Ingvar Hagelund <ingvar@redpill-linpro.com> - 4.1.0-0.2.git.a50ebc2
- First wrap for fedora/copr, based on upstream specfile
- Added a patch replacing old lwp calls with curl on el5
- Added a patch removing -Werror for i386 on el5 and el6

* Mon May 19 2014 Yves Hwang <yveshwang@gmail.com> - 4.0.0
- Compatible with varnish >= 4.0.0

* Fri Apr 25 2014 Yves Hwang <yveshwang@gmail.com> - 2.2.1
- Compatible with varnish >= 3.0.5
- #109 Do not set CURLOPT_NOBODY if we have data to send.
- #108 libcurl issues HEAD instead of PUT in rhel5
- Fix an issue related to unsafe sigalarm use in older versions of libcurl.

* Mon Oct 28 2013 Dridi Boukelmoune <dridi.boukelmoune@gmail.com> - 2.2-1
- Added /etc/varnish/agent_secret in the files list

* Sat Mar 16 2013 Patricio Bruna <pbruna@itlinux.cl> - 2.2-1
- Added dependencies for rpmbuild

* Fri Feb 22 2013 Kristian Lyngstøl <kristian@bohemians.org> - 2.2-1
- Release

* Wed Jan 30 2013 Kristian Lyngstol <kristian@bohemians.org> - 2.1-1
- 2.1 dev version

* Fri Jan 18 2013 Lasse Karstensen <lkarsten@varnish-software.com> - 2.0-1
- Initial version.
